#!/usr/bin/env python3

# Author::    Justin Flannery  (mailto:juftin@juftin.com)

"""
camply __init__ file
"""

from ._version import __version__, __camply__

__all__ = [
    "__version__",
    "__camply__",
]
